<!DOCTYPE HTML>
<html>
    <head>
        <link rel="Stylesheet" type="text/css" href="{{ site.root }}/static/css/style.css">
        <link rel="Stylesheet" type="text/css" href="{{ site.root }}/static/css/tango.css">
        <title>{% block title %}{{ site.title }}{% endblock %}</title>
        <meta name="keywords" content="{{ site.keywords }}"/>
        <meta name="description" content="{{ site.description }}"/>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    </head>

    <body>
        <div id="container">
            {% block container %}
                {{ page.content }}
            {% endblock %}
        </div>
        <div id="footer">
            <span>
                Copyright © {{ site.time.strftime("%Y") }} {{ site.author }}.
                Powered by <a href="http://simiki.org/" target="_blank">Simiki</a>.
            </span>
        </div>
        {% include "stat.html" %}
    </body>
</html>
