/*  
Theme Name: Simple
Author: Tanky Woo<me@tankywoo.com>
Author URI: http://www.wutianqi.com/
Description: Default theme for simiki.
Version: 0.1
License: The MIT License (MIT)
Tags: simple, single-columns, code, codehighlight, white, markdown
*/

/* Global Configuration */
/* IE6 ignores this and uses default size of 16pt */
html>body { font-size: 14px; }

html {
    font-size: 100%;
    overflow-y: scroll;
    -webkit-text-size-adjust: 100%;
    -ms-text-size-adjust: 100%;
}

body {
    font-family: "Helvetica Neue", "Segoe UI", Arial, Sans-Serif;
    line-height: 1.5em;
    background-color: whitesmoke;
}

a { color: #0645ad; text-decoration: none; }
a:visited { color: #0b0080; }
a:hover { color: #06e; text-decoration: underline; }
a:active { color: #faa700; }

p { margin: 0 0 1.5em 0; text-align: justify; }

h1, h2, h3, h4, h5, h6 {
    font-weight: normal;
    color: #111;
    line-height: 1em;
}

h1 { font-size: 2.0em; }
h2 { font-size: 1.6em; border-bottom: 1px solid #ddd; padding-bottom: 5px; overflow:hidden }
h3 { font-size: 1.4em; }
h4 { font-size: 1.2em; }
h5 { font-size: 1.0em; }
h6 { font-size: 0.8em; }

blockquote {
    color: #666;
    margin: 0;
    padding-left: 3em;
    border-left: 0.4em #eee solid;
}

hr {
    border: 1px solid silver;
    margin: 1em 0;
    padding: 0;
}

b, strong { font-weight: bold; }

ul, ol {
    margin: 1.5em 0;
    padding-left: 1.5em;
    line-height: 1.5em;
}

ul li { list-style-type: square; }

ul li p { margin: 0; }

img {
    border: 0;
    vertical-align: middle;
    margin: 0 auto;
    max-width: 100%;
}

table {
    border-collapse: collapse;
    border-spacing: 0;
    margin-bottom: 1em;
    border: 1px solid #ccc;
}

td {
    vertical-align: top;
    padding: 3px 6px;
}

/* Optimization for pre and code tag */
pre, code { 
    font-family: Consolas, "DejaVu Sans Mono", "Lucida Console", Monaco, Andale Mono, "MS Gothic", monospace;
    font-size: 13px;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    overflow: auto;
}

code {
    color: #666;
    background-color: #eee;
    margin: 0 2px;
    padding: 1px 3px;
}

pre { 
    border: 1px solid #eee;
    padding: 8px 12px;
    white-space: pre;
    white-space: -moz-pre-wrap; /* Firefox */
    white-space: -pre-wrap;     /* ancient Opera */
    white-space: -o-pre-wrap;   /* newer Opera */
    white-space: pre-wrap;      /* Chrome; W3C standard */
    word-wrap: break-word;      /* IE */
}

pre code {
    border: 0px !important;
    padding: 0;
    color: #000;
    background-color: #f8f8f8;
}

/* Custom Configuration */
#container {
    background: white;
    width: 50em;
    line-height: 1.5em;
    margin: 1.5em auto 3em auto;
    padding: 1.5em 2em;
    border: 1px solid #ccc;
    box-shadow: 2px 2px 8px #aaa;
    -webkit-box-shadow: 2px 2px 8px #aaa;
    -moz-box-shadow: 2px 2px 8px #aaa;
}

#wiki_title, #title {
    text-align: center;
    font-size: 2em;
    line-height: 1.5em;
    padding-bottom: 10px;
    margin: 20px 0;
}

#title {
    border-bottom: 1px dashed #eee;
}

#header {
}

#footer {
    margin: 10px auto;
    color: grey;
    font-size: 80%;
    text-align: center;
}

li.pagelist {
    width: 100%;
    margin-right: 1.5em;
    list-style-type: none;
    white-space: nowrap;
    overflow: hidden;
}

li.pagelist:before {
    content: "\0BB \020";
}

#index ul { margin: 0; }

/* Table of Contents */
.toc {
    margin: 0 0.5em;
    padding: 0.5em 1em;
    border: 1px solid silver;
    background-color: #ecf5ff;
    float: right;
    display: block;
    font-size: 90%;
}

.toc > .toctitle {
    display: block;
    text-align: center;
    font-weight: bold;
    margin-bottom: 1em;
}

.toc ul {
    margin: 0;
}

/* Hackers */
/* Hacker for codehilite */
table.codehilitetable {
    border-collapse: separate;
    border: 1px solid #eee;
    margin: 14px 0;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}

.codehilitetable pre {
    margin: 0;
    border: 0 none;
    box-shadow: none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
}

.codehilitetable td {
    border: 0 none;
    padding: 0;
    margin: 0;
}

/* Clear the float problem */
.clearfix:after {
    visibility: hidden;
    clear: both;
    font-size: 0;
    content: ".";
    display: block;
    height: 0;
}


table.hlcodetable {
    border: 1px solid #eee;
    border-collapse: separate !important;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}

.hlcodetable td {
    padding: 0;
    border: none;
}

.hlcodetable .linenodiv {
    border-right: 1px solid #ccc;
}

.hlcodetable .linenodiv pre {
    margin: 0;
    border: none;
}

.hlcodetable .hlcode pre {
    margin: 0;
    border: none;
}
