pre .hll { background-color: #ffffcc }
pre  { background: #f8f8f8; }
pre .c { color: #8f5902; font-style: italic } /* Comment */
pre .g { color: #000000 } /* Generic */
pre .k { color: #204a87; font-weight: bold } /* Keyword */
pre .l { color: #000000 } /* Literal */
pre .n { color: #000000 } /* Name */
pre .o { color: #ce5c00; font-weight: bold } /* Operator */
pre .x { color: #000000 } /* Other */
pre .p { color: #000000; font-weight: bold } /* Punctuation */
pre .cm { color: #8f5902; font-style: italic } /* Comment.Multiline */
pre .cp { color: #8f5902; font-style: italic } /* Comment.Preproc */
pre .c1 { color: #8f5902; font-style: italic } /* Comment.Single */
pre .cs { color: #8f5902; font-style: italic } /* Comment.Special */
pre .gd { color: #a40000 } /* Generic.Deleted */
pre .ge { color: #000000; font-style: italic } /* Generic.Emph */
pre .gr { color: #ef2929 } /* Generic.Error */
pre .gh { color: #000080; font-weight: bold } /* Generic.Heading */
pre .gi { color: #00A000 } /* Generic.Inserted */
pre .go { color: #000000; font-style: italic } /* Generic.Output */
pre .gp { color: #8f5902 } /* Generic.Prompt */
pre .gs { color: #000000; font-weight: bold } /* Generic.Strong */
pre .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
pre .gt { color: #a40000; font-weight: bold } /* Generic.Traceback */
pre .kc { color: #204a87; font-weight: bold } /* Keyword.Constant */
pre .kd { color: #204a87; font-weight: bold } /* Keyword.Declaration */
pre .kn { color: #204a87; font-weight: bold } /* Keyword.Namespace */
pre .kp { color: #204a87; font-weight: bold } /* Keyword.Pseudo */
pre .kr { color: #204a87; font-weight: bold } /* Keyword.Reserved */
pre .kt { color: #204a87; font-weight: bold } /* Keyword.Type */
pre .ld { color: #000000 } /* Literal.Date */
pre .m { color: #0000cf; font-weight: bold } /* Literal.Number */
pre .s { color: #4e9a06 } /* Literal.String */
pre .na { color: #c4a000 } /* Name.Attribute */
pre .nb { color: #204a87 } /* Name.Builtin */
pre .nc { color: #000000 } /* Name.Class */
pre .no { color: #000000 } /* Name.Constant */
pre .nd { color: #5c35cc; font-weight: bold } /* Name.Decorator */
pre .ni { color: #ce5c00 } /* Name.Entity */
pre .ne { color: #cc0000; font-weight: bold } /* Name.Exception */
pre .nf { color: #000000 } /* Name.Function */
pre .nl { color: #f57900 } /* Name.Label */
pre .nn { color: #000000 } /* Name.Namespace */
pre .nx { color: #000000 } /* Name.Other */
pre .py { color: #000000 } /* Name.Property */
pre .nt { color: #204a87; font-weight: bold } /* Name.Tag */
pre .nv { color: #000000 } /* Name.Variable */
pre .ow { color: #204a87; font-weight: bold } /* Operator.Word */
pre .w { color: #f8f8f8; text-decoration: underline } /* Text.Whitespace */
pre .mf { color: #0000cf; font-weight: bold } /* Literal.Number.Float */
pre .mh { color: #0000cf; font-weight: bold } /* Literal.Number.Hex */
pre .mi { color: #0000cf; font-weight: bold } /* Literal.Number.Integer */
pre .mo { color: #0000cf; font-weight: bold } /* Literal.Number.Oct */
pre .sb { color: #4e9a06 } /* Literal.String.Backtick */
pre .sc { color: #4e9a06 } /* Literal.String.Char */
pre .sd { color: #8f5902; font-style: italic } /* Literal.String.Doc */
pre .s2 { color: #4e9a06 } /* Literal.String.Double */
pre .se { color: #4e9a06 } /* Literal.String.Escape */
pre .sh { color: #4e9a06 } /* Literal.String.Heredoc */
pre .si { color: #4e9a06 } /* Literal.String.Interpol */
pre .sx { color: #4e9a06 } /* Literal.String.Other */
pre .sr { color: #4e9a06 } /* Literal.String.Regex */
pre .s1 { color: #4e9a06 } /* Literal.String.Single */
pre .ss { color: #4e9a06 } /* Literal.String.Symbol */
pre .bp { color: #3465a4 } /* Name.Builtin.Pseudo */
pre .vc { color: #000000 } /* Name.Variable.Class */
pre .vg { color: #000000 } /* Name.Variable.Global */
pre .vi { color: #000000 } /* Name.Variable.Instance */
pre .il { color: #0000cf; font-weight: bold } /* Literal.Number.Integer.Long */
.hlcode pre .hll { background-color: #ffffcc }
.hlcode pre  { background: #f8f8f8; }
.hlcode pre .c { color: #8f5902; font-style: italic } /* Comment */
.hlcode pre .g { color: #000000 } /* Generic */
.hlcode pre .k { color: #204a87; font-weight: bold } /* Keyword */
.hlcode pre .l { color: #000000 } /* Literal */
.hlcode pre .n { color: #000000 } /* Name */
.hlcode pre .o { color: #ce5c00; font-weight: bold } /* Operator */
.hlcode pre .x { color: #000000 } /* Other */
.hlcode pre .p { color: #000000; font-weight: bold } /* Punctuation */
.hlcode pre .cm { color: #8f5902; font-style: italic } /* Comment.Multiline */
.hlcode pre .cp { color: #8f5902; font-style: italic } /* Comment.Preproc */
.hlcode pre .c1 { color: #8f5902; font-style: italic } /* Comment.Single */
.hlcode pre .cs { color: #8f5902; font-style: italic } /* Comment.Special */
.hlcode pre .gd { color: #a40000 } /* Generic.Deleted */
.hlcode pre .ge { color: #000000; font-style: italic } /* Generic.Emph */
.hlcode pre .gr { color: #ef2929 } /* Generic.Error */
.hlcode pre .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.hlcode pre .gi { color: #00A000 } /* Generic.Inserted */
.hlcode pre .go { color: #000000; font-style: italic } /* Generic.Output */
.hlcode pre .gp { color: #8f5902 } /* Generic.Prompt */
.hlcode pre .gs { color: #000000; font-weight: bold } /* Generic.Strong */
.hlcode pre .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.hlcode pre .gt { color: #a40000; font-weight: bold } /* Generic.Traceback */
.hlcode pre .kc { color: #204a87; font-weight: bold } /* Keyword.Constant */
.hlcode pre .kd { color: #204a87; font-weight: bold } /* Keyword.Declaration */
.hlcode pre .kn { color: #204a87; font-weight: bold } /* Keyword.Namespace */
.hlcode pre .kp { color: #204a87; font-weight: bold } /* Keyword.Pseudo */
.hlcode pre .kr { color: #204a87; font-weight: bold } /* Keyword.Reserved */
.hlcode pre .kt { color: #204a87; font-weight: bold } /* Keyword.Type */
.hlcode pre .ld { color: #000000 } /* Literal.Date */
.hlcode pre .m { color: #0000cf; font-weight: bold } /* Literal.Number */
.hlcode pre .s { color: #4e9a06 } /* Literal.String */
.hlcode pre .na { color: #c4a000 } /* Name.Attribute */
.hlcode pre .nb { color: #204a87 } /* Name.Builtin */
.hlcode pre .nc { color: #000000 } /* Name.Class */
.hlcode pre .no { color: #000000 } /* Name.Constant */
.hlcode pre .nd { color: #5c35cc; font-weight: bold } /* Name.Decorator */
.hlcode pre .ni { color: #ce5c00 } /* Name.Entity */
.hlcode pre .ne { color: #cc0000; font-weight: bold } /* Name.Exception */
.hlcode pre .nf { color: #000000 } /* Name.Function */
.hlcode pre .nl { color: #f57900 } /* Name.Label */
.hlcode pre .nn { color: #000000 } /* Name.Namespace */
.hlcode pre .nx { color: #000000 } /* Name.Other */
.hlcode pre .py { color: #000000 } /* Name.Property */
.hlcode pre .nt { color: #204a87; font-weight: bold } /* Name.Tag */
.hlcode pre .nv { color: #000000 } /* Name.Variable */
.hlcode pre .ow { color: #204a87; font-weight: bold } /* Operator.Word */
.hlcode pre .w { color: #f8f8f8; text-decoration: underline } /* Text.Whitespace */
.hlcode pre .mf { color: #0000cf; font-weight: bold } /* Literal.Number.Float */
.hlcode pre .mh { color: #0000cf; font-weight: bold } /* Literal.Number.Hex */
.hlcode pre .mi { color: #0000cf; font-weight: bold } /* Literal.Number.Integer */
.hlcode pre .mo { color: #0000cf; font-weight: bold } /* Literal.Number.Oct */
.hlcode pre .sb { color: #4e9a06 } /* Literal.String.Backtick */
.hlcode pre .sc { color: #4e9a06 } /* Literal.String.Char */
.hlcode pre .sd { color: #8f5902; font-style: italic } /* Literal.String.Doc */
.hlcode pre .s2 { color: #4e9a06 } /* Literal.String.Double */
.hlcode pre .se { color: #4e9a06 } /* Literal.String.Escape */
.hlcode pre .sh { color: #4e9a06 } /* Literal.String.Heredoc */
.hlcode pre .si { color: #4e9a06 } /* Literal.String.Interpol */
.hlcode pre .sx { color: #4e9a06 } /* Literal.String.Other */
.hlcode pre .sr { color: #4e9a06 } /* Literal.String.Regex */
.hlcode pre .s1 { color: #4e9a06 } /* Literal.String.Single */
.hlcode pre .ss { color: #4e9a06 } /* Literal.String.Symbol */
.hlcode pre .bp { color: #3465a4 } /* Name.Builtin.Pseudo */
.hlcode pre .vc { color: #000000 } /* Name.Variable.Class */
.hlcode pre .vg { color: #000000 } /* Name.Variable.Global */
.hlcode pre .vi { color: #000000 } /* Name.Variable.Instance */
.hlcode pre .il { color: #0000cf; font-weight: bold } /* Literal.Number.Integer.Long */
